@@ -3,4 +3,5 @@ from .pytestarch import get_evaluable_architecture  # noqa: F401 E401
 from .pytestarch import (  # noqa: F401 E401; noqa: F401 E401
     get_evaluable_architecture_for_module_objects,
 )
-from .query_language.base_language import Rule  # noqa: F401
+from .query_language.rule import Rule  # noqa: F401
+from .query_language.diagrams.diagram_rule import DiagramRule  # noqa: F401
